/**********************************************************************/
/*                                                                    */
/* This program may be used, executed, copied, modified and           */
/* distributed without royalty for the purpose of developing, using,  */
/* marketing, or distributing.                                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* DESCRIPTION:  An implementation of the                             */
/*  javax.activity.propertygroup.PropertyGroup interface which allows */
/* testing of the interaction of the Activity Service with objects    */
/* that implement this interface.                                     */
/*  The principal interaction is through the 'completed',             */
/* 'suspended' and 'resumed' methods which the Activity Service uses  */
/* to notify changes to the Activity state.                           */
/*                                                                    */
/**********************************************************************/

package com.ibm.activity.hls;

import javax.activity.*;
import javax.activity.propertygroup.*;


/**
 * A test implementation of the <code>PropertyGroup</code> interface.
 * Events (such as the calling of the interface methods) are logged to a
 * <code>TestLog</code> object. In addition to this logging, the
 * various interface methods can be configured to execute test 'commands'
 * using a table of <code>Command</code> objects that are passed in
 * from the PropertyGroupManager that creates each instance.
 */
public final class PropertyGroupImpl implements PropertyGroup
   {
   private  TestLog  _testLog = null;
   private  String   _name    = null;
   private java.util.Hashtable _actions = null;

   public PropertyGroupImpl (String name, TestLog testLog)
      {
      Trace.out ("PropertyGroupImpl.PropertyGroupImpl");
      _testLog = testLog;
      _name    = name;
      }  // end PropertyGroupImpl c'tor

   public void setCommands (java.util.Hashtable  commands)
      {
      _actions = commands;
      }


// *********************************************
// *** PropertyGroup Interface  METHODS ********
// *********************************************


   public String getPropertyGroupName ()
      {
      Trace.out ("PropertyGroupImpl.getPropertyGroupName");
      return _name;
      }

   public void completed ()
      {
      Trace.out ("PropertyGroupImpl.completed");
      _testLog.log ("PropertyGroup " + _name + " completed");

      if (_actions != null)
         {
         Command tc = (Command) _actions.get ("completed");
         if (tc != null)
            tc.runCommands ();
         }  // end if

      }

   public void suspended ()
      {
      Trace.out ("PropertyGroupImpl.suspended");
      _testLog.log ("PropertyGroup " + _name + " suspended");

      if (_actions != null)
         {
         Command tc = (Command) _actions.get ("suspended");
         if (tc != null)
            tc.runCommands ();
         }  // end if
      }

   public void resumed ()
      {
      Trace.out ("PropertyGroupImpl.resumed");
      _testLog.log ("PropertyGroup " + _name + " resumed");

      if (_actions != null)
         {
         Command tc = (Command) _actions.get ("resumed");
         if (tc != null)
            tc.runCommands ();
         }  // end if
      }

   }  // end class PropertyGroupImpl
