/**********************************************************************/
/*                                                                    */
/* This program may be used, executed, copied, modified and           */
/* distributed without royalty for the purpose of developing, using,  */
/* marketing, or distributing.                                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* DESCRIPTION:  An implementation of the                             */
/*  javax.activity.propertygroup.PropertyGroupManager interface       */
/* which allows testing of the interaction of the Activity Service    */
/* with objects that implement this interface.                        */
/*                                                                    */
/* The only method of interest is the 'create' method, which is       */
/* called by the Activity Service to create a new PropertyGroup when  */
/* an Activity is begun.                                              */
/*                                                                    */
/**********************************************************************/

package com.ibm.activity.hls;

import javax.activity.*;
import javax.activity.propertygroup.*;


/**
 * A test implementation of the <code>PropertyGroupImpl</code> interface.
 * Used to create and configure the corresponding PropertyGroup which is
 * part of each Activity.  The PropertyGroupManager is supplied by the
 * ServiceManager which is registered with the Activity Service.
 * A table of <code>Command</code> objects can be set up using the
 * addResponse method.  This table is passed to each PropertyGroup that is
 * created causing a series of test commands to be executed when the
 * corresponding interface method is called by the Activity Service.
 */

public final class PropertyGroupManagerImpl implements PropertyGroupManager
   {
   private  TestLog  _testLog = null;
   private  String   _name    = null;
   private  java.util.Hashtable _actions = new java.util.Hashtable ();



   public PropertyGroupManagerImpl (java.lang.String name, TestLog testLog)
      {
      Trace.out ("PropertyGroupManagerImpl.PropertyGroupManagerImpl");
      _testLog = testLog;
      _name    = name;
      }  // end PropertyGroupManagerImpl c'tor

   public void addResponse (String method, Command command)
      {
      Trace.out ("PropertyGroupManagerImpl.addResponse " + method);
      _actions.put (method, command);
      }  // end PropertyGroupManagerImpl.addResponse


// ****************************************************
// *** PropertyGroupManager Interface  METHODS ********
// ****************************************************

   public PropertyGroup create (PropertyGroup parent, GlobalId globalId)
      {
      Trace.out ("PropertyGroupManagerImpl.create");
      String pname = null;
      if (parent != null)
         pname = parent.getPropertyGroupName ();

      _testLog.log ("PropertyGroupManager " + _name +
         " creating new PropertyGroup with parent " + pname);

      PropertyGroupImpl result =  new PropertyGroupImpl (_name, _testLog);
      // now set command parameters etc
      result.setCommands (_actions);
      return result;
      }

   public PropertyGroupContext marshalRequest (PropertyGroup pg)
      {
      Trace.out ("PropertyGroupManagerImpl.marshalRequest");
      return null;
      }

   public PropertyGroupContext marshalResponse (PropertyGroup pg)
      {
      Trace.out ("PropertyGroupManagerImpl.marshalResponse");
      return null;
      }

   public PropertyGroup unmarshalRequest (PropertyGroupContext ctx,
      PropertyGroup pg, PropertyGroup parent, GlobalId globalId)
      {
      Trace.out ("PropertyGroupManagerImpl.unmarshalRequest");
      return null;
      }

   public void unmarshalResponse (PropertyGroupContext ctx, PropertyGroup pg)
      {
      Trace.out ("PropertyGroupManagerImpl.unmarshalResponse");
      }

   public java.util.Properties getProperties ()
      {
      Trace.out ("PropertyGroupManagerImpl.getProperties");
      return null;
      }

   public PropertyGroup recoverPropertyGroup (PropertyGroup parent,
      GlobalId globalId)
      throws SystemException
      {
      Trace.out ("PropertyGroupManagerImpl.recoverPropertyGroup");

      String pname = null;
      if (parent != null)
         pname = parent.getPropertyGroupName ();

      _testLog.log ("PropertyGroupManager " + _name +
         " recovering PropertyGroup with parent " + pname);

      PropertyGroupImpl result =  new PropertyGroupImpl (_name, _testLog);
      // now set command parameters etc
      result.setCommands (_actions);
      return result;
      }


   }  // end class PropertyGroupManagerImpl
