/**********************************************************************/
/*                                                                    */
/* This program may be used, executed, copied, modified and           */
/* distributed without royalty for the purpose of developing, using,  */
/* marketing, or distributing.                                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* DESCRIPTION:                                                       */
/* A Trace utility class for the testcases.                           */
/* Trace is turned on and off via the corresponding methods.          */
/* Just a single method 'out' is used for tracing strings.            */
/* The trace destination can be set via the setDestination method.    */
/*                                                                    */
/**********************************************************************/

package com.ibm.activity.hls;

import java.io.PrintWriter;

/**
 * A Trace utility class for the JSR95 TCK testcases.
 * A series of static methods.
 * Trace is turned on and off via the corresponding methods.
 * Just a single method 'out' is used for tracing strings.
 * The trace destination can be set via the setDestination method.
 */

public class Trace
   {
   /**
    * Outputs the given String to the trace stream if tracing is turned on.
    * @param text   The <code>String</code> to output
    */
   public static void out (String text)
      {
      if (_traceFlag)
         out.println (text);
      }

   /**
    * Outputs the stacktrace from the given exception
    * to the trace stream if tracing is turned on.
    * @param e   The <code>Exception</code> to trace
    */
   public static void exception (Exception e)
      {
      if (_traceFlag)
         e.printStackTrace (out);
      }

   /**
    * Sets the stream onto which trace data is output.
    * @param dest   The <code>PrintWriter</code> wrapper of the output stream.
    *   This is initially set to System.out
    */
   public static void setDestination (PrintWriter dest)
      {
      out = dest;
      }

   /**
    * Sets tracing on.
    */
   public static void on ()
      {
      _traceFlag = true;
      }

   /**
    * Sets tracing off.
    */
   public static void off ()
      {
      _traceFlag = false;
      }

   private static boolean _traceFlag = false;
   private static PrintWriter  out = new PrintWriter (System.out, true);
   }  // end class Trace
