
/**********************************************************************/
/*                                                                    */
/* This program may be used, executed, copied, modified and           */
/* distributed without royalty for the purpose of developing, using,  */
/* marketing, or distributing.                                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* DESCRIPTION: Turns a text String into a series of commands which   */
/* can be executed by the TestActivity class.                         */
/*                                                                    */
/*                                                                    */
/**********************************************************************/

package com.ibm.activity.unittest;

import java.io.*;           // StreamTokenizer etc
import java.util.Vector;
import com.ibm.activity.hls.Command;



/**
 * A utitlity class to accept a String which can be parsed and
 * executed in the TestActivity class
 */

final class TestCommand implements Command
   {
   /**
    * Create an TestCommand with the given String
    * @param cmds     the String representing the commands to execute
    * @param ta       the TestActivity object to be used to execute the cmds
    */
   public TestCommand (java.lang.String cmds, TestActivity ta)
      {
      _cmds = cmds;
      _ta    = ta;
      }  // end c'tor

   /**
    * Parses the command string into a series of tokens for each line
    * and passes it to the TestActivity class for execution.
    */
   public void runCommands ()
      {
      // build tokeniser from string and extract a line at a time
      StreamTokenizer  rdr = new StreamTokenizer (new StringReader (_cmds));
      rdr.eolIsSignificant (true);
      rdr.lowerCaseMode (true);
      rdr.slashSlashComments (true);
      rdr.slashStarComments (true);

      Vector tokens = new Vector ();
      int token     = StreamTokenizer.TT_EOL;

      // while more lines
      while (token != StreamTokenizer.TT_EOF)
         {
         tokens.clear ();
         try
            {
            token = rdr.nextToken ();
            while (token != StreamTokenizer.TT_EOL   &&
               token != StreamTokenizer.TT_EOF )
               {
               if (token == StreamTokenizer.TT_NUMBER)
                  tokens.add ("" + (int) rdr.nval);
               else if (rdr.sval != null)
                  tokens.add (rdr.sval);

               token = rdr.nextToken ();
               }  // end while

            //    call ta.executeCmd (Vector)
            _ta.executeCmd (tokens);
            }
         catch (IOException e) {}
         }  // end while

      }  // end runCommands

   private java.lang.String   _cmds = null;
   private TestActivity       _ta   = null;

   }  // end class TestCommand
